package eu.printingin3d.models.models.printer;

import java.io.File;
import java.io.IOException;
import java.util.Arrays;

import eu.printingin3d.javascad.coords.Angles3d;
import eu.printingin3d.javascad.coords.Coords3d;
import eu.printingin3d.javascad.coords.Dims3d;
import eu.printingin3d.javascad.enums.Side;
import eu.printingin3d.javascad.models.Abstract3dModel;
import eu.printingin3d.javascad.models.Cube;
import eu.printingin3d.javascad.models.Cylinder;
import eu.printingin3d.javascad.models.Extendable3dModel;
import eu.printingin3d.javascad.tranzitions.Difference;
import eu.printingin3d.javascad.tranzitions.Union;
import eu.printingin3d.javascad.utils.SaveScadFiles;

public class MaxFilamentHolder extends Extendable3dModel {
	private static final double BASE_LENGTH    = 50;
	private static final double BASE_WIDTH     = 10;
	private static final double BASE_THICKNESS =  8;
	
	private static final double BOLT_HOLE_DIAM =  5;
	private static final double BOLT_DIST      = 17;
	
	private static final double AXIS_DIAM      =  8;
	private static final double AXIS_FRAME_DIAM= 18;
	
	public MaxFilamentHolder() {
		Cube base = new Cube(new Dims3d(BASE_LENGTH, BASE_WIDTH, BASE_THICKNESS));
		Abstract3dModel axisHolder = new Cylinder(BASE_WIDTH, AXIS_FRAME_DIAM/2)
			.rotate(Angles3d.ROTATE_MINUS_X)
			.align(Side.BOTTOM, base, true);
		this.baseModel = new Difference(
				new Union(base, axisHolder),
				new Cylinder(BASE_THICKNESS+1, BOLT_HOLE_DIAM/2)
						.moves(Arrays.asList(Coords3d.xOnly(-BOLT_DIST), Coords3d.xOnly(+BOLT_DIST))),
				new Cylinder(BASE_WIDTH+1, AXIS_DIAM/2)
					.rotate(Angles3d.ROTATE_MINUS_X)
					.align(Side.CENTER, axisHolder, true)
		);
	}
	
	public static void main(String[] args) throws IOException {
		new SaveScadFiles(new File("C:/temp")).
				addModel("max_filament_holder.scad", new MaxFilamentHolder().rotate(Angles3d.ROTATE_MINUS_X)).
				saveScadFiles();
	}
}
