package eu.printingin3d.models.models.printer;

import java.io.File;
import java.io.IOException;

import eu.printingin3d.javascad.coords.Coords3d;
import eu.printingin3d.javascad.enums.AlignType;
import eu.printingin3d.javascad.enums.Side;
import eu.printingin3d.javascad.models.Cylinder;
import eu.printingin3d.javascad.models.Extendable3dModel;
import eu.printingin3d.javascad.tranzitions.Difference;
import eu.printingin3d.javascad.tranzitions.Union;
import eu.printingin3d.javascad.utils.SaveScadFiles;

public class RollBearingHolder extends Extendable3dModel {
	private static final double BEARING_DIAMETER = 22.3;
	private static final double BEARING_DEPTH = 5.0;
	private static final double INSIDE_DIAMETER = 18.0;
	private static final double SKIRT_WIDTH = 3.0;
	private static final double SKIRT_THICKNESS = 3.0;
	private static final double INSIDE_MARGIN = 3.0;
	private static final double ROLL_INSIDE_DIAMETER = 51.0;
	
	public RollBearingHolder() {
		Cylinder base = new Cylinder(BEARING_DEPTH+INSIDE_MARGIN, ROLL_INSIDE_DIAMETER/2.0);
		
		this.baseModel = new Difference(
				new Union(base,
						new Cylinder(SKIRT_THICKNESS, ROLL_INSIDE_DIAMETER/2.0+SKIRT_WIDTH)
							.align(new Side(AlignType.CENTER, AlignType.CENTER, AlignType.MIN), base, true)), 
				new Cylinder(BEARING_DEPTH, BEARING_DIAMETER/2.0)
					.align(new Side(AlignType.CENTER, AlignType.CENTER, AlignType.MIN), base, true)
					.move(Coords3d.zOnly(-0.005)),
				new Cylinder(BEARING_DEPTH+INSIDE_MARGIN+1.0, INSIDE_DIAMETER/2.0)
					.align(Side.CENTER, base, true));
	}
	
	
	public static void main(String[] args) throws IOException {
		new SaveScadFiles(new File("C:/temp")).
				addModel("roll_bearing_holder.scad", new RollBearingHolder()).
				saveScadFiles();
	}
}
